==> testsuite-3.0.50-beta1.tar.gz: testsuite/src/BaseTrait.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Component\Utility\Xss;

/**
 * Test Suite Base Trait.
 */
trait BaseTrait {

  /**
   * The list of areas represent the areas where modules are.
   *
   * @var array
   */
  protected $areas = [
    'core',
    'contrib',
    'custom',
  ];

  /**
   * The list of directories represent the directories where phpunit tests are.
   *
   * @var array
   */
  protected $directories = [
    'Unit',
    'Kernel',
    'Functional',
    'FunctionalJavascript',
  ];

  /**
   * Formats the message.
   *
   * @param string $message
   *   The error report message.
   *
   * @return string|bool
   *   The message formated or FALSE.
   */
  protected function formatMessage($message) {
    if ($message != NULL) {
      $newMessage = str_replace("\n\n\n", "<br />", $message);
      $newMessage = str_replace("\n\n", "<br />", $newMessage);
      $newMessage = str_replace("\n", "<br />", $newMessage);
      return Xss::filterAdmin($newMessage);
    }
    else {
      return FALSE;
    }
  }

  /**
   * Takes the full file path and returns the file name.
   *
   * @param string $filePath
   *   The file we are reporting on.
   *
   * @return string
   *   The filename.
   */
  protected function getFileName($filePath) {
    if (preg_match('/\([^)]*\)/', $filePath)) {
      $fileParts = preg_split('/\s\(/', $filePath);
      $filePath = $fileParts[0];
    }
    $filePart = explode(DIRECTORY_SEPARATOR, $filePath);
    if (isset($fileParts[1])) {
      return end($filePart) . " (" . $fileParts[1];
    }
    else {
      return end($filePart);
    }

  }

  /**
   * Displays an Emoji representing results of a vulnerability check.
   *
   * @param int $ifVulnerability
   *   The type of emogi to display.
   *
   * @return markup
   *   Markup to be rendered.
   */
  protected function getEmoji($ifVulnerability) {
    switch ($ifVulnerability) {
      case 0:
        return '<span class="testsuite-vulnerability-emoji" title="No vulnerabilities">✔️</span>';

      case 1:
        return '<span class="testsuite-vulnerability-emoji" title="Vulnerabilities detected. Please go to the details page to view a vulnerability report.">❗</span>';

      case 2:
        return '<span class="testsuite-vulnerability-emoji" title="The checker relies on either a composer.json or package.json file for information on a package. A reliable vulnerability check could not be made.">❔</span>';

      default:
        return '<span class="testsuite-vulnerability-emoji" title="The version could not be identified through composer.json or package.json. There are vulnerabilities with a version or versions of this package. Please double check the version in the top of the css or js files and compare with the version specified in the vulnerability report. Without a specifing the version in the json file I cannot perfectly realize the version with this software.">❓</span>';
    }
  }

}

==> testsuite-3.0.51-beta1.tar.gz: testsuite/src/BaseTrait.php <==
<?php

namespace Drupal\testsuite;

use Drupal\Component\Utility\Xss;

/**
 * Test Suite Base Trait.
 */
trait BaseTrait {

  /**
   * The list of regex expressions.
   *
   * Semver_version
   * https://semver.org/#is-there-a-suggested-regular-expression-regex-to-check-a-semver-string.
   *
   * @var array
   */
  protected $regex = [
    'string' => '/^[a-zA-Z0-9_\-]+$/',
    'string_space' => '/^[a-zA-Z0-9_\-\s]+$/',
    'name_dot_name' => '/^[a-zA-Z0-9_\-\.]+(\.[a-zA-Z0-9_\-\.]+)?$/',
    'css_file_name' => '/^[a-zA-Z0-9_\-\.]+(\.css)?$/',
    'js_file_name' => '/^[a-zA-Z0-9_\-\.]+(\.js)?$/',
    'number_single' => '/^[0-9]{1}$/',
    'numbers' => '/^[0-9]+$/',
    'http_check' => '/^https?/',
    'semver_version' => '/^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+([0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?$/',
  ];

  /**
   * The list of types.
   *
   * @var array
   */
  protected $types = [
    'module',
    'theme',
  ];

  /**
   * The list of areas represent the areas where modules are.
   *
   * @var array
   */
  protected $areas = [
    'core',
    'contrib',
    'custom',
  ];

  /**
   * The list of directories represent the directories where phpunit tests are.
   *
   * @var array
   */
  protected $directories = [
    'Unit',
    'Kernel',
    'Functional',
    'FunctionalJavascript',
  ];

  /**
   * Formats the message.
   *
   * @param string $message
   *   The error report message.
   *
   * @return string|bool
   *   The message formated or FALSE.
   */
  protected function formatMessage($message) {
    if ($message != NULL) {
      $newMessage = str_replace("\n\n\n", "<br />", $message);
      $newMessage = str_replace("\n\n", "<br />", $newMessage);
      $newMessage = str_replace("\n", "<br />", $newMessage);
      return Xss::filterAdmin($newMessage);
    }
    else {
      return FALSE;
    }
  }

  /**
   * Takes the full file path and returns the file name.
   *
   * @param string $filePath
   *   The file we are reporting on.
   *
   * @return string
   *   The filename.
   */
  protected function getFileName($filePath) {
    if (preg_match('/\([^)]*\)/', $filePath)) {
      $fileParts = preg_split('/\s\(/', $filePath);
      $filePath = $fileParts[0];
    }
    $filePart = explode(DIRECTORY_SEPARATOR, $filePath);
    if (isset($fileParts[1])) {
      return end($filePart) . " (" . $fileParts[1];
    }
    else {
      return end($filePart);
    }

  }

  /**
   * Displays an Emoji representing results of a vulnerability check.
   *
   * @param int $ifVulnerability
   *   The type of emogi to display.
   *
   * @return markup
   *   Markup to be rendered.
   */
  protected function getEmoji($ifVulnerability) {
    switch ($ifVulnerability) {
      case 0:
        return '<span class="testsuite-vulnerability-emoji" title="No vulnerabilities">✔️</span>';

      case 1:
        return '<span class="testsuite-vulnerability-emoji" title="Vulnerabilities detected. Please go to the details page to view a vulnerability report.">❗</span>';

      case 2:
        return '<span class="testsuite-vulnerability-emoji" title="The checker relies on either a composer.json or package.json file for information on a package. A reliable vulnerability check could not be made. If this is a css or js file internal files are files that do not get code from an exterior source like a CDN. They are usually safe unless there is a vunerability report on the module itself. Exteral files will matter more and I will try to check them for vulnerabilities.">❔</span>';

      case 3:
        return '<span class="testsuite-vulnerability-emoji" title="The version could not be identified through composer.json or package.json. There are vulnerabilities with a version or versions of this package. Please double check the version in the top of the css or js files and compare with the version specified in the vulnerability report. Without a specifing the version in the json file I cannot perfectly realize the version with this software.">❓</span>';

      case 4:
        return '<span class="testsuite-vulnerability-emoji" title="Internal scripts are not tested. They are a component of either Drupal, a module or a theme.">❎</span>';

      default:
        return '<span class="testsuite-vulnerability-emoji" title="The version could not be identified through composer.json or package.json. There are vulnerabilities with a version or versions of this package. Please double check the version in the top of the css or js files and compare with the version specified in the vulnerability report. Without a specifing the version in the json file I cannot perfectly realize the version with this software.">❓</span>';
    }
  }

  /**
   * The array of databases.
   *
   * @var array
   */
  protected $databases = [
    'lp_core_library' => 0,
    'lp_installed_package' => 1,
    'lp_installed_library' => 2,
    'lp_installed_module' => 3,
    'lp_module_library' => 4,
  ];

}
